@@ -4,18 +4,13 @@ Net::CIDR::Lookup::Tie
 
 =head1 DESCRIPTION
 
-This is a L<Tie::Hash> interface to L<Net::CIDR::Lookup>, see there for
-details.
+This is a Tie::Hash interface to Net::CIDR::Lookup, see there for details.
 
 The tied hash accepts net blocks as keys in the same syntax as
-C<Net::CIDR::Lookup->add()> or C<add_range(>) and stores arbitrary (with the
-exception of C<undef>) scalar values under these. The same coalescing as in
-C<Net::CIDR::Lookup> takes place, so if you add any number of different keys
-you may end up with a hash containing I<less> keys if any mergers took place.
-
-Of course you can retrieve the corresponding net block's value for any key that
-is I<contained> within that block, so the number of possible lookup keys is
-usually far greater than that of explicitly stored key/value pairs.
+Net::CIDR::Lookup::add()/add_range() and stores arbitrary scalar values under these.
+The same coalescing as in Net::CIDR::Lookup takes place, so if you add any number of
+different keys you might end up with a hash containing I<less> keys if any
+mergers took place.
 
 =head1 SYNOPSIS
 
@@ -30,16 +25,6 @@ usually far greater than that of explicitly stored key/value pairs.
 
   foreach(keys %h) { ... }			 # Do anything you'd do with a regular hash
 
-=head1 HISTORY
-
-=over 1
-
-=item v0.3 First CPAN release
-
-=item v0.41 Version bumped to sync with IPv6 version
-
-=back
-
 =head1 METHODS
 
 =cut
@@ -51,9 +36,9 @@ use warnings;
 use Carp;
 use Net::CIDR::Lookup;
 
-$Net::CIDR::Lookup::Tie::VERSION = sprintf "%d.%d", q$Revision: 0.41 $ =~ m/ (\d+) \. (\d+) /xg;
+$Net::CIDR::Lookup::Tie::VERSION = sprintf "%d.%d", q$Revision: 0.3 $ =~ m/ (\d+) \. (\d+) /xg;
 
-sub TIEHASH {   ## no critic (Subroutines::RequireArgUnpacking)
+sub TIEHASH {
     my $class = shift;
     bless { tree => Net::CIDR::Lookup->new(@_) }, $class;
 }
@@ -63,8 +48,7 @@ sub TIEHASH {   ## no critic (Subroutines::RequireArgUnpacking)
 Stores a value under a given key
 
 =cut
-
-sub STORE { ## no critic (Subroutines::RequireArgUnpacking)
+sub STORE {
     my $self = shift;
     undef $self->{keys};
     if($_[0] =~ /-/) {
@@ -79,7 +63,6 @@ sub STORE { ## no critic (Subroutines::RequireArgUnpacking)
 Fetches the value stored under a given key
 
 =cut
-
 sub FETCH {
     my ($self, $key) = @_;
     $self->{tree}->lookup($key);
@@ -90,7 +73,6 @@ sub FETCH {
 Gets the first key in the hash. Used for iteration with each()
 
 =cut
-
 sub FIRSTKEY {
     my $self = shift;
     $self->_updkeys;
@@ -102,7 +84,6 @@ sub FIRSTKEY {
 Gets the next key from the hash. Used for iteration with each()
 
 =cut
-
 sub NEXTKEY {
     each %{shift->{keys}};
 }
@@ -113,7 +94,6 @@ Tests if a key is in the hash. Also returns true for blocks or addresses
 contained within a block that was actually stored.
 
 =cut
-
 sub EXISTS {
     my ($self, $key) = @_;
     $self->_updkeys;
@@ -126,7 +106,6 @@ Delete a key from the hash. Note that the same restrictions as for Net::CIDR::Lo
 regarding netblock splitting apply!
 
 =cut
-
 sub DELETE {
     carp('Deletions are not supported by tied ' . __PACKAGE__ . ' objects yet!');
 }
@@ -136,7 +115,6 @@ sub DELETE {
 Deletes all keys and their values.
 
 =cut
-
 sub CLEAR {
     my $self = shift;
     $self->{tree}->clear;
@@ -147,7 +125,6 @@ sub CLEAR {
 Returns the number of keys in the hash
 
 =cut
-
 sub SCALAR {
     my $self = shift;
     $self->_updkeys;
@@ -159,7 +136,6 @@ sub SCALAR {
 Private method to update the internal key cache used for iteration
 
 =cut
-
 sub _updkeys {
     my $self = shift;
 
